@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Authorization;
-$Net::Amazon::S3::Authorization::VERSION = '0.91';
+$Net::Amazon::S3::Authorization::VERSION = '0.92';
 use Moose 0.85;
 
 # ABSTRACT: Authorization context base class
@@ -30,7 +30,7 @@ Net::Amazon::S3::Authorization - Authorization context base class
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 DESCRIPTION
 
@@ -38,11 +38,11 @@ Authorization context provides an access to authorization informations
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
