@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Authorization::IAM;
-$Net::Amazon::S3::Authorization::IAM::VERSION = '0.91';
+$Net::Amazon::S3::Authorization::IAM::VERSION = '0.92';
 # ABSTRACT: IAM authorization information
 
 use Moose 0.85;
@@ -61,7 +61,7 @@ Net::Amazon::S3::Authorization::IAM - IAM authorization information
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
@@ -101,11 +101,11 @@ If you use IAM, please consider to add proper C<use> statement into your code.
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
