@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Request::Role::HTTP::Header;
 # ABSTRACT: HTTP Header Role
-$Net::Amazon::S3::Request::Role::HTTP::Header::VERSION = '0.91';
+$Net::Amazon::S3::Request::Role::HTTP::Header::VERSION = '0.92';
 use MooseX::Role::Parameterized;
 
 parameter name => (
@@ -71,15 +71,15 @@ Net::Amazon::S3::Request::Role::HTTP::Header - HTTP Header Role
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
