@@ -1,11 +1,13 @@
 package Net::Amazon::S3::Request::Role::HTTP::Header::Copy_source;
 # ABSTRACT: x-amz-copy-source header role
-$Net::Amazon::S3::Request::Role::HTTP::Header::Copy_source::VERSION = '0.91';
+$Net::Amazon::S3::Request::Role::HTTP::Header::Copy_source::VERSION = '0.92';
 use Moose::Role;
 
+use Net::Amazon::S3::Constants;
+
 with 'Net::Amazon::S3::Request::Role::HTTP::Header' => {
     name => '_copy_source',
-    header => 'x-amz-copy-source',
+    header => Net::Amazon::S3::Constants->HEADER_COPY_SOURCE,
     isa => 'Maybe[Str]',
     required => 0,
     default => sub {
@@ -33,15 +35,15 @@ Net::Amazon::S3::Request::Role::HTTP::Header::Copy_source - x-amz-copy-source he
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
