@@ -1,11 +1,13 @@
 package Net::Amazon::S3::Request::Role::HTTP::Header::Encryption;
 # ABSTRACT: x-amz-server-side-encryption header role
-$Net::Amazon::S3::Request::Role::HTTP::Header::Encryption::VERSION = '0.91';
+$Net::Amazon::S3::Request::Role::HTTP::Header::Encryption::VERSION = '0.92';
 use Moose::Role;
 
+use Net::Amazon::S3::Constants;
+
 with 'Net::Amazon::S3::Request::Role::HTTP::Header' => {
     name => 'encryption',
-    header => 'x-amz-server-side-encryption',
+    header => Net::Amazon::S3::Constants->HEADER_SERVER_ENCRYPTION,
     isa => 'Maybe[Str]',
     required => 0,
 };
@@ -24,15 +26,15 @@ Net::Amazon::S3::Request::Role::HTTP::Header::Encryption - x-amz-server-side-enc
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
