@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Request::Role::HTTP::Method;
 # ABSTRACT: HTTP method role
-$Net::Amazon::S3::Request::Role::HTTP::Method::VERSION = '0.91';
+$Net::Amazon::S3::Request::Role::HTTP::Method::VERSION = '0.92';
 use MooseX::Role::Parameterized;
 
 use Net::Amazon::S3::HTTPRequest;
@@ -43,15 +43,15 @@ Net::Amazon::S3::Request::Role::HTTP::Method - HTTP method role
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
