@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Request::Role::Query::Param::Max_keys;
 # ABSTRACT: max-keys query param role
-$Net::Amazon::S3::Request::Role::Query::Param::Max_keys::VERSION = '0.91';
+$Net::Amazon::S3::Request::Role::Query::Param::Max_keys::VERSION = '0.92';
 use Moose::Role;
 
 with 'Net::Amazon::S3::Request::Role::Query::Param' => {
@@ -25,15 +25,15 @@ Net::Amazon::S3::Request::Role::Query::Param::Max_keys - max-keys query param ro
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
