@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Signature;
 # ABSTRACT: S3 Signature implementation base class
-$Net::Amazon::S3::Signature::VERSION = '0.91';
+$Net::Amazon::S3::Signature::VERSION = '0.92';
 use Moose;
 
 has http_request => (
@@ -80,7 +80,7 @@ Net::Amazon::S3::Signature - S3 Signature implementation base class
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 METHODS
 
@@ -107,11 +107,11 @@ or query parameter (if signing uri)
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
