@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Vendor::Generic;
-$Net::Amazon::S3::Vendor::Generic::VERSION = '0.91';
+$Net::Amazon::S3::Vendor::Generic::VERSION = '0.92';
 use Moose 0.85;
 
 # ABSTRACT: Generic S3 vendor
@@ -20,7 +20,7 @@ Net::Amazon::S3::Vendor::Generic - Generic S3 vendor
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
@@ -39,11 +39,11 @@ version 0.91
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
