@@ -1,6 +1,6 @@
 package Shared::Examples::Net::Amazon::S3::Fixture;
 # ABSTRACT: used for testing to provide test fixtures
-$Shared::Examples::Net::Amazon::S3::Fixture::VERSION = '0.91';
+$Shared::Examples::Net::Amazon::S3::Fixture::VERSION = '0.92';
 use parent qw[ Exporter::Tiny ];
 
 use HTTP::Status;
@@ -36,10 +36,12 @@ sub fixture {
 }
 
 sub error_fixture {
-    my ($error_code, $http_status) = @_;
+    my ($error_code, $http_status, $error_message) = @_;
 
-    my $error_message = $error_code;
-    $error_message =~ s/ (?<=[[:lower:]]) ([[:upper:]])/ \L$1\E/gx;
+	unless (defined $error_message) {
+		$error_message = $error_code;
+		$error_message =~ s/ (?<=[[:lower:]]) ([[:upper:]])/ \L$1\E/gx;
+	}
 
     return response_fixture (
         response_code => $http_status,
@@ -69,15 +71,15 @@ Shared::Examples::Net::Amazon::S3::Fixture - used for testing to provide test fi
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
