@@ -1,6 +1,6 @@
 package Shared::Examples::Net::Amazon::S3::Request;
 # ABSTRACT: used for testing and as example
-$Shared::Examples::Net::Amazon::S3::Request::VERSION = '0.91';
+$Shared::Examples::Net::Amazon::S3::Request::VERSION = '0.92';
 use strict;
 use warnings;
 
@@ -200,15 +200,15 @@ Shared::Examples::Net::Amazon::S3::Request - used for testing and as example
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 AUTHOR
 
-Leo Lapworth <llap@cpan.org>
+Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
